@@ -6,7 +6,7 @@
 ( cd usr/lib ; ln -sf ../../../usr/sbin/sendmail sendmail )
 ( cd etc/rc.d/init.d ; rm -rf postfix )
 ( cd etc/rc.d/init.d ; ln -sf ../../../usr/sbin/postfix postfix )
-#%% begin initialize postfix-2.6.9-i586-P1
+#%% begin initialize postfix-2.7.4-i586-P1
 ( cd /etc
   if [ ! -f aliases ] ; then
     mv aliases-new aliases
@@ -18,7 +18,7 @@
 
 ( cd /etc
   if  ! grep submission services 1>/dev/null 2>/dev/null; then
-     cat >> services << "EOF2"
+     cat >> services <<EOF2
 submission      587/tcp
 submission      587/udp
 EOF2
@@ -28,7 +28,7 @@ EOF2
       /bin/killall -HUP inetd
   fi
 )
-    
+
 (  cd /etc/postfix
 
     for conf_file in LICENSE TLS_LICENSE access aliases bounce.cf.default canonical generic header_checks main.cf main.cf.default makedefs.out master.cf relocated transport virtual ; do
